@@ -10,8 +10,14 @@ from .forms import *
 
 #admin.site.register(SegmentType, SegmentTypeAdmin)
 
-class WordAdmin(admin.ModelAdmin):
-    model = Word
+class LemmaAdmin(admin.ModelAdmin):
+    model = Lemma
     list_display = ('Label','getSpellings')
 
-admin.site.register(Word, WordAdmin)
+admin.site.register(Lemma, LemmaAdmin)
+
+class WordFormAdmin(admin.ModelAdmin):
+    model = WordForm
+    list_display = ('Label','getSpellings','getTranscriptions')
+
+admin.site.register(Lemma, LemmaAdmin)
