@@ -205,6 +205,10 @@ class SyntacticCategory(models.Model):
     Description = models.CharField(max_length=100,blank=True,null=True)
     CategoryType = models.CharField(max_length=100,blank=True,null=True)
 
+    def __unicode__(self):
+        return self.Label
+
+
 #class CatRelationship(models.Model):
 #    Word = models.ForeignKey('Word')
 #    Category = models.ForeignKey(SyntacticCategory)
@@ -219,6 +223,9 @@ class Transcription(models.Model):
     StressPattern = models.CharField(max_length=100,blank=True,null=True)
     CVSkel = models.CharField(max_length=100,blank=True,null=True)
 
+    def __unicode__(self):
+        return self.Transcription
+
     #def getCVStruct(self):
     #    if self.CVSkel is not None:
     #        return self.CVSkel
@@ -235,14 +242,23 @@ class Transcription(models.Model):
 class Orthography(models.Model):
     Spelling = models.CharField(max_length=250)
 
+    def __unicode__(self):
+        return self.Spelling
+
 class WordForm(models.Model):
     Lemma = models.ForeignKey('Lemma')
     Orthographies = models.ManyToManyField(Orthography)
     Transcriptions = models.ManyToManyField(Transcription)
     Frequency = models.FloatField(blank=True,null=True)
 
+    def getTranscriptions(self):
+        return ".".join(str(t) for t in wf.Transcriptions.all())
+
+    def getSpellings(self):
+        return ", ".join(str(s) for s in wf.Orthographies.all())
+
     def __unicode__(self):
-        return u'%s' % self.Label
+        return u'%s' % self.Lemma.Label
 
 class Lemma(models.Model):
     FreqDict = models.ForeignKey(FreqDict)
@@ -251,8 +267,10 @@ class Lemma(models.Model):
     Frequency = models.FloatField(blank=True,null=True)
 
     #objects = WordManager()
+    def __unicode__(self):
+        return self.Label
 
-    def getUR(self):
+    def getTranscriptions(self):
         return ".".join(str(t) for wf in WordForm.objects.filter(Word=self) for t in wf.Transcriptions.all())
 
     def getSpellings(self):
