@@ -1,7 +1,6 @@
 
 import csv
 
-from django.core.management import call_command
 from django.core.context_processors import csrf
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import authenticate,login
@@ -12,7 +11,7 @@ from django.core.files import File
 
 from .models import *
 from .forms import *
-from .helper import fetch_celex_resource
+from .helper import fetch_celex_resource,reset
 
 
 #old
@@ -59,8 +58,7 @@ def reset(request):
         if request.method == 'POST':
             form = ResetForm(request.POST)
             if form.is_valid() and form.cleaned_data['reset']:
-                c = FreqDict.objects.get_or_create(Name='CELEX')[0]
-                c.loadInfo()
+                reset()
                 return redirect(index)
             else:
                 form = ResetForm()
